@@ -5,6 +5,7 @@ cd ../mingw-build
 unzip /tmp/pd.zip
 cd pd/lib
 tar xzf /home/msp/work/asio/asio2.3-sdk-src.tgz
+mv ASIOSDK2.3 ASIOSDK
 cd ../src
 rm semaphore.h pthread.h sched.h pthreadVC.lib pthreadVC.dll
 cp ~/pd/src/pd.rc ~/pd/src/pd.ico .
@@ -32,9 +33,9 @@ do
 done
 
 cd ../..
-mv pd/lib/ASIOSDK2.3 /tmp/ASIOSDK2.3-save
+mv pd/lib/ASIOSDK /tmp/ASIOSDK-save
 rm -f /tmp/pd-out.zip
 zip -r /tmp/pd-out.zip pd
-mv /tmp/ASIOSDK2.3-save pd/lib/ASIOSDK2.3
+mv /tmp/ASIOSDK-save pd/lib/ASIOSDK
 echo ++++++++++++++++ /tmp/pd-out.zip ++++++++++++++++++
 exit 0
