@@ -5,10 +5,11 @@
 /*  send~, delread~, throw~, catch~ */
 
 #include "m_pd.h"
+#include <string.h>
 extern int ugen_getsortno(void);
 
 #define DEFDELVS 64             /* LATER get this from canvas at DSP time */
-static int delread_zero = 0;    /* four bytes of zero for delread~, vd~ */
+static const int delread_zero = 0;    /* four bytes of zero for delread~, vd~*/
 
 /* ----------------------------- delwrite~ ----------------------------- */
 static t_class *sigdelwrite_class;
@@ -51,6 +52,13 @@ static void sigdelwrite_updatesr(t_sigdelwrite *x, t_float sr) /* added by Mathi
     }
 }
 
+static void sigdelwrite_clear (t_sigdelwrite *x) /* added by Orm Finnendahl */
+{
+  if (x->x_cspace.c_n > 0)
+    memset(x->x_cspace.c_vec, 0, sizeof(t_sample)*(x->x_cspace.c_n + XTRASAMPS));
+}
+
+
     /* routine to check that all delwrites/delreads/vds have same vecsize */
 static void sigdelwrite_checkvecsize(t_sigdelwrite *x, int vecsize)
 {
@@ -136,6 +144,8 @@ static void sigdelwrite_setup(void)
     CLASS_MAINSIGNALIN(sigdelwrite_class, t_sigdelwrite, x_f);
     class_addmethod(sigdelwrite_class, (t_method)sigdelwrite_dsp,
         gensym("dsp"), A_CANT, 0);
+    class_addmethod(sigdelwrite_class, (t_method)sigdelwrite_clear,
+                    gensym("clear"), 0);
 }
 
 /* ----------------------------- delread~ ----------------------------- */
@@ -168,13 +178,11 @@ static void *sigdelread_new(t_symbol *s, t_floatarg f)
 
 static void sigdelread_float(t_sigdelread *x, t_float f)
 {
-    int samps;
     t_sigdelwrite *delwriter =
         (t_sigdelwrite *)pd_findbyclass(x->x_sym, sigdelwrite_class);
     x->x_deltime = f;
     if (delwriter)
     {
-        int delsize = delwriter->x_cspace.c_n;
         x->x_delsamps = (int)(0.5 + x->x_sr * x->x_deltime)
             + x->x_n - x->x_zerodel;
         if (x->x_delsamps < x->x_n) x->x_delsamps = x->x_n;
