@@ -137,7 +137,7 @@ static void *sigrsqrt_new(void)
 
 static t_int *sigrsqrt_perform(t_int *w)
 {
-    t_sample *in = *(t_sample **)(w+1), *out = *(t_sample **)(w+2);
+    t_sample *in = (t_sample *)w[1], *out = (t_sample *)w[2];
     t_int n = *(t_int *)(w+3);
     while (n--)
     {
@@ -196,7 +196,7 @@ static void *sigsqrt_new(void)
 
 t_int *sigsqrt_perform(t_int *w)    /* not static; also used in d_fft.c */
 {
-    t_sample *in = *(t_sample **)(w+1), *out = *(t_sample **)(w+2);
+    t_sample *in = (t_sample *)w[1], *out = (t_sample *)w[2];
     t_int n = *(t_int *)(w+3);
     while (n--)
     {
@@ -252,8 +252,8 @@ static void *sigwrap_new(void)
 
 static t_int *sigwrap_perform(t_int *w)
 {
-    t_sample *in = *(t_sample **)(w+1), *out = *(t_sample **)(w+2);
-    t_int n = *(t_int *)(w+3);
+    t_sample *in = (t_sample *)w[1], *out = (t_sample *)w[2];
+    t_int n = (t_int)w[3];
     while (n--)
     {
         t_sample f = *in++;
@@ -267,8 +267,8 @@ static t_int *sigwrap_perform(t_int *w)
      /* old buggy version that sometimes output 1 instead of 0 */
 static t_int *sigwrap_old_perform(t_int *w)
 {
-    t_sample *in = *(t_sample **)(w+1), *out = *(t_sample **)(w+2);
-    t_int n = *(t_int *)(w+3);
+    t_sample *in = (t_sample *)w[1], *out = (t_sample *)w[2];
+    t_int n = (t_int)w[3];
     while (n--)
     {
         t_sample f = *in++;
@@ -315,8 +315,8 @@ static void *mtof_tilde_new(void)
 
 static t_int *mtof_tilde_perform(t_int *w)
 {
-    t_sample *in = *(t_sample **)(w+1), *out = *(t_sample **)(w+2);
-    t_int n = *(t_int *)(w+3);
+    t_sample *in = (t_sample *)w[1], *out = (t_sample *)w[2];
+    t_int n = (t_int)w[3];
     for (; n--; in++, out++)
     {
         t_sample f = *in;
@@ -364,8 +364,8 @@ static void *ftom_tilde_new(void)
 
 static t_int *ftom_tilde_perform(t_int *w)
 {
-    t_sample *in = *(t_sample **)(w+1), *out = *(t_sample **)(w+2);
-    t_int n = *(t_int *)(w+3);
+    t_sample *in = (t_sample *)w[1], *out = (t_sample *)w[2];
+    t_int n = (t_int)w[3];
     for (; n--; in++, out++)
     {
         t_sample f = *in;
@@ -408,8 +408,8 @@ static void *dbtorms_tilde_new(void)
 
 static t_int *dbtorms_tilde_perform(t_int *w)
 {
-    t_sample *in = *(t_sample **)(w+1), *out = *(t_sample **)(w+2);
-    t_int n = *(t_int *)(w+3);
+    t_sample *in = (t_sample *)w[1], *out = (t_sample *)w[2];
+    t_int n = (t_int)w[3];
     for (; n--; in++, out++)
     {
         t_sample f = *in;
@@ -458,8 +458,8 @@ static void *rmstodb_tilde_new(void)
 
 static t_int *rmstodb_tilde_perform(t_int *w)
 {
-    t_sample *in = *(t_sample **)(w+1), *out = *(t_sample **)(w+2);
-    t_int n = *(t_int *)(w+3);
+    t_sample *in = (t_sample *)w[1], *out = (t_sample *)w[2];
+    t_int n = (t_int)w[3];
     for (; n--; in++, out++)
     {
         t_sample f = *in;
@@ -507,8 +507,8 @@ static void *dbtopow_tilde_new(void)
 
 static t_int *dbtopow_tilde_perform(t_int *w)
 {
-    t_sample *in = *(t_sample **)(w+1), *out = *(t_sample **)(w+2);
-    t_int n = *(t_int *)(w+3);
+    t_sample *in = (t_sample *)w[1], *out = (t_sample *)w[2];
+    t_int n = (t_int)w[3];
     for (; n--; in++, out++)
     {
         t_sample f = *in;
@@ -557,8 +557,8 @@ static void *powtodb_tilde_new(void)
 
 static t_int *powtodb_tilde_perform(t_int *w)
 {
-    t_sample *in = *(t_sample **)(w+1), *out = *(t_sample **)(w+2);
-    t_int n = *(t_int *)(w+3);
+    t_sample *in = (t_sample *)w[1], *out = (t_sample *)w[2];
+    t_int n = (t_int)w[3];
     for (; n--; in++, out++)
     {
         t_sample f = *in;
