@@ -39,7 +39,7 @@
 static void alsa_checkiosync( void);
 static void alsa_numbertoname(int iodev, char *devname, int nchar);
 static int alsa_jittermax;
-#define ALSA_DEFJITTERMAX 3
+#define ALSA_DEFJITTERMAX 5
 
     /* don't assume we can turn all 31 bits when doing float-to-fix;
     otherwise some audio drivers (e.g. Midiman/ALSA) wrap around. */
@@ -429,7 +429,7 @@ int alsa_send_dacs(void)
     static double timenow;
     double timelast;
     t_sample *fp, *fp1, *fp2;
-    int i, j, k, err, iodev, result, ch, resync = 0;;
+    int i, j, k, err, iodev, result, ch, goterror = 0;
     int chansintogo, chansouttogo;
     unsigned int transfersize;
 
@@ -568,8 +568,12 @@ int alsa_send_dacs(void)
                 if (result < 0)
                     fprintf(stderr, "read reset error %d\n", result);
             }
-            else fprintf(stderr, "read other error %d\n", result);
-            resync = 1;
+            else
+            {
+                fprintf(stderr, "read error: %s (%d)\n",
+                    strerror(-result), result);
+                goterror = 1;
+            }
         }
 
         /* zero out the output buffer */
@@ -610,8 +614,12 @@ int alsa_send_dacs(void)
                 if (result < 0)
                     fprintf(stderr, "read reset error %d\n", result);
             }
-            else fprintf(stderr, "read other error %d\n", result);
-            resync = 1;
+            else
+            {
+                fprintf(stderr, "read error: %s (%d)\n",
+                    strerror(-result), result);
+                goterror = 1;
+            }
         }
         if (alsa_indev[iodev].a_sampwidth == 4)
         {
@@ -667,17 +675,23 @@ int alsa_send_dacs(void)
         if (!checkcountdown--)
         {
             checkcountdown = 10;
-            if (alsa_nindev + alsa_noutdev > 1)
+            if (alsa_nindev + alsa_noutdev > 1 && !goterror)
                 alsa_checkiosync();   /*  check I/O are in sync */
         }
     }
-    return SENDDACS_YES;
+        /* if there were errors we can't use this as a timing source.
+        LATER get it together to close A/D/A when this happens and
+        switch to software clock.  Choosing 5000 msec here so it will be
+        clear to user that we're not timing right. */
+    if (goterror)
+        sys_microsleep(5000);
+    return (SENDDACS_YES);
 }
 
 void alsa_printstate( void)
 {
     int i, result, iodev = 0;
-    snd_pcm_sframes_t indelay = 0, outdelay = 0;
+    snd_pcm_sframes_t indelay = 0, inavail = 0, outdelay = 0, outavail = 0;
     if (sys_audioapi != API_ALSA)
     {
         error("restart-audio: implemented for ALSA only.");
@@ -685,21 +699,24 @@ void alsa_printstate( void)
     }
     if (STUFF->st_inchannels)
     {
-        result = snd_pcm_delay(alsa_indev[iodev].a_handle, &indelay);
+        result = snd_pcm_avail_delay(alsa_indev[iodev].a_handle, &inavail,
+            &indelay);
         if (result < 0)
-            post("snd_pcm_delay 1 failed");
-        else post("in delay %d", indelay);
+            post("snd_pcm_delay (in) returned %d", result);
+        post("in delay %d available %d", indelay, inavail);
     }
     if (STUFF->st_outchannels)
     {
-        result = snd_pcm_delay(alsa_outdev[iodev].a_handle, &outdelay);
+        result = snd_pcm_avail_delay(alsa_outdev[iodev].a_handle, &outavail,
+            &outdelay);
         if (result < 0)
-            post("snd_pcm_delay 2 failed");
-        else post("out delay %d", outdelay);
+            post("snd_pcm_delay (out) returned %d", result);
+        post("out delay %d available %d", outdelay, outavail);
     }
-    post("sum %d (%d mod 64)\n", indelay + outdelay, (indelay+outdelay)%64);
+    post("sum delay %d available %d", indelay + outdelay, inavail + outavail);
 
     post("buf samples %d", alsa_buf_samps);
+    post("");
 }
 
 void alsa_putzeros(int iodev, int n)
@@ -740,13 +757,13 @@ static void alsa_checkiosync( void)
 {
     int i, result, giveup = 50, alreadylogged = 0, iodev = 0, err;
     snd_pcm_sframes_t minphase, maxphase, thisphase, outdelay;
-
     while (1)
     {
         if (giveup-- <= 0)
         {
             post("tried but couldn't sync A/D/A");
-            alsa_jittermax += 1;
+            if (alsa_jittermax < 6)
+                alsa_jittermax += 1;
             return;
         }
         minphase = 0x7fffffff;
@@ -754,7 +771,18 @@ static void alsa_checkiosync( void)
         for (iodev = 0; iodev < alsa_noutdev; iodev++)
         {
             if ((result = snd_pcm_state(alsa_outdev[iodev].a_handle))
-                != SND_PCM_STATE_RUNNING && result != SND_PCM_STATE_XRUN)
+                == SND_PCM_STATE_XRUN)
+            {
+                    sys_log_error(ERR_DATALATE);
+                    alreadylogged = 1;
+                    snd_pcm_recover(alsa_outdev[iodev].a_handle,
+		        SND_PCM_STATE_XRUN, 0);
+                    if (snd_pcm_state(alsa_outdev[iodev].a_handle)
+                        != SND_PCM_STATE_RUNNING)
+                            post("snd_pcm_recover failed: state now %d",
+                                snd_pcm_state(alsa_outdev[iodev].a_handle));
+            }
+            else if (result != SND_PCM_STATE_RUNNING)
             {
                 if (sys_verbose)
                     post("restarting output device from state %d",
@@ -763,24 +791,14 @@ static void alsa_checkiosync( void)
                     check_error(err, 0, "restart failed");
             }
             result = snd_pcm_delay(alsa_outdev[iodev].a_handle, &outdelay);
+                /* In a mysterious change in the API ca. 2017, "result" can
+                be negative the number of late samples instead of indicating
+                an error.  In this case, reset and query again. */
             if (result < 0)
             {
-                snd_pcm_prepare(alsa_outdev[iodev].a_handle);
-                result = snd_pcm_delay(alsa_outdev[iodev].a_handle, &outdelay);
-            }
-#ifdef DEBUG_ALSA_XFER
-            post("outfifo %d %d %d",
-                callno, xferno, outdelay);
-#endif
-            if (result < 0)
-            {
-                post("output snd_pcm_delay failed: %s", snd_strerror(result));
-                if (snd_pcm_status(alsa_outdev[iodev].a_handle,
-                    alsa_status) < 0)
-                        post("output snd_pcm_status failed");
-                else post("astate %d",
-                     snd_pcm_status_get_state(alsa_status));
-                return;
+                snd_pcm_reset(alsa_outdev[iodev].a_handle);
+                result = snd_pcm_delay(alsa_outdev[iodev].a_handle,
+                    &outdelay);
             }
             thisphase = alsa_buf_samps - outdelay;
             if (thisphase < minphase)
@@ -793,7 +811,18 @@ static void alsa_checkiosync( void)
         for (iodev = 0; iodev < alsa_nindev; iodev++)
         {
             if ((result = snd_pcm_state(alsa_indev[iodev].a_handle))
-                != SND_PCM_STATE_RUNNING && result != SND_PCM_STATE_XRUN)
+                == SND_PCM_STATE_XRUN)
+            {
+                    sys_log_error(ERR_DATALATE);
+                    alreadylogged = 1;
+                    snd_pcm_recover(alsa_indev[iodev].a_handle,
+		        SND_PCM_STATE_XRUN, 0);
+                    if (snd_pcm_state(alsa_indev[iodev].a_handle)
+                        != SND_PCM_STATE_RUNNING)
+                            post("snd_pcm_recover failed: state now %d",
+                                snd_pcm_state(alsa_indev[iodev].a_handle));
+            }
+            else if (result != SND_PCM_STATE_RUNNING)
             {
                 if (sys_verbose)
                     post("restarting input device from state %d",
@@ -802,25 +831,6 @@ static void alsa_checkiosync( void)
                     check_error(err, 1, "restart failed");
             }
             result = snd_pcm_delay(alsa_indev[iodev].a_handle, &thisphase);
-            if (result < 0)
-            {
-                snd_pcm_prepare(alsa_indev[iodev].a_handle);
-                result = snd_pcm_delay(alsa_indev[iodev].a_handle, &thisphase);
-            }
-#ifdef DEBUG_ALSA_XFER
-            post("infifo  %d %d %d",
-                callno, xferno, thisphase);
-#endif
-            if (result < 0)
-            {
-                post("output snd_pcm_delay failed: %s", snd_strerror(result));
-                if (snd_pcm_status(alsa_outdev[iodev].a_handle,
-                    alsa_status) < 0)
-                    post("output snd_pcm_status failed");
-                else post("astate %d",
-                     snd_pcm_status_get_state(alsa_status));
-                return;
-            }
             if (thisphase < minphase)
                 minphase = thisphase;
             if (thisphase > maxphase)
@@ -841,7 +851,7 @@ static void alsa_checkiosync( void)
         {
             result = snd_pcm_delay(alsa_outdev[iodev].a_handle, &outdelay);
             if (result < 0)
-                break;
+                outdelay = result;
             thisphase = alsa_buf_samps - outdelay;
             if (thisphase > minphase + DEFDACBLKSIZE)
             {
@@ -858,7 +868,7 @@ static void alsa_checkiosync( void)
         {
             result = snd_pcm_delay(alsa_indev[iodev].a_handle, &thisphase);
             if (result < 0)
-                break;
+                thisphase = 0;
             if (thisphase > minphase + DEFDACBLKSIZE)
             {
                 alsa_getzeros(iodev, 1);
