@@ -412,7 +412,7 @@ void sys_sockerror(char *s)
 #else
     int err = errno;
 #endif
-    post("%s: %s (%d)\n", s, strerror(err), err);
+    error("%s: %s (%d)\n", s, strerror(err), err);
 }
 
 void sys_addpollfn(int fd, t_fdpollfn fn, void *ptr)
@@ -487,9 +487,9 @@ static int socketreceiver_doread(t_socketreceiver *x)
     for (indx = intail; first || (indx != inhead);
         first = 0, (indx = (indx+1)&(INBUFSIZE-1)))
     {
-            /* if we hit a semi that isn't preceeded by a \, it's a message
+            /* if we hit a semi that isn't preceded by a \, it's a message
             boundary.  LATER we should deal with the possibility that the
-            preceeding \ might itself be escaped! */
+            preceding \ might itself be escaped! */
         char c = *bp++ = inbuf[indx];
         if (c == ';' && (!indx || inbuf[indx-1] != '\\'))
         {
@@ -930,7 +930,7 @@ void glob_watchdog(t_pd *dummy)
 }
 #endif
 
-static void sys_init_deken()
+static void sys_init_deken( void)
 {
     const char*os =
 #if defined __linux__
@@ -959,11 +959,13 @@ static void sys_init_deken()
         "i386"
 #elif defined(__ppc__)
         "ppc"
+#elif defined(__aarch64__)
+        "arm64"
 #elif defined (__ARM_ARCH)
         "armv" stringify(__ARM_ARCH)
-# if defined(__BYTE_ORDER__) && defined(__ORDER_LITTLE_ENDIAN__)
-#  if __BYTE_ORDER__ == __ORDER_LITTLE_ENDIAN__
-        "l"
+# if defined(__BYTE_ORDER__) && defined(__ORDER_BIG_ENDIAN__)
+#  if __BYTE_ORDER__ == __ORDER_BIG_ENDIAN__
+        "b"
 #  endif
 # endif
 #else
@@ -994,20 +996,13 @@ static int sys_do_startgui(const char *libdir)
     const int maxtry = 20;
     int ntry = 0, portno = FIRSTPORTNUM;
     int xsock = -1, dumbo = -1;
-#ifdef _WIN32
-    short version = MAKEWORD(2, 0);
-    WSADATA nobby;
-#else
+#ifndef _WIN32
     int stdinpipe[2];
     pid_t childpid;
 #endif /* _WIN32 */
 
     sys_init_fdpoll();
 
-#ifdef _WIN32
-    if (WSAStartup(version, &nobby)) sys_sockerror("WSAstartup");
-#endif /* _WIN32 */
-
     if (sys_guisetportnumber)  /* GUI exists and sent us a port number */
     {
         struct sockaddr_in server = {0};
@@ -1241,7 +1236,7 @@ static int sys_do_startgui(const char *libdir)
         strcat(wishbuf, "/" PDBINDIR WISH);
         sys_bashfilename(wishbuf, wishbuf);
 
-        spawnret = _spawnl(P_NOWAIT, wishbuf, WISH, scriptbuf, portbuf, 0);
+        spawnret = _spawnl(P_NOWAIT, wishbuf, WISH, scriptbuf, portbuf, NULL);
         if (spawnret < 0)
         {
             perror("spawnl");
@@ -1291,6 +1286,7 @@ static int sys_do_startgui(const char *libdir)
              PD_BUGFIX_VERSION, PD_TEST_VERSION,
              apibuf, apibuf2, sys_font, sys_fontweight);
     sys_vgui("set pd_whichapi %d\n", sys_audioapi);
+    sys_vgui("set zoom_open %d\n", sys_zoom_open == 2);
 
     sys_init_deken();
     return (0);
@@ -1301,7 +1297,7 @@ void sys_setrealtime(const char *libdir)
     char cmdbuf[MAXPDSTRING];
 #if defined(__linux__) || defined(__FreeBSD_kernel__)
         /*  promote this process's priority, if we can and want to.
-        If sys_hipriority not specfied (-1), we assume real-time was wanted.
+        If sys_hipriority not specified (-1), we assume real-time was wanted.
         Starting in Linux 2.6 one can permit real-time operation of Pd by]
         putting lines like:
                 @audio - rtprio 99
