@@ -14,14 +14,12 @@
 #ifdef _WIN32
 #include <io.h>
 #endif
-extern t_pd *newest;
 
 t_class *scalar_define_class;
 
 static void *scalar_define_new(t_symbol *s, int argc, t_atom *argv)
 {
     t_atom a[9];
-    t_glist *gl;
     t_canvas *x, *z = canvas_getcurrent();
     t_symbol *templatesym = &s_float, *asym = gensym("#A");
     t_template *template;
@@ -86,7 +84,7 @@ static void *scalar_define_new(t_symbol *s, int argc, t_atom *argv)
         saved file or copy buffer */
     pd_bind(&x->gl_obj.ob_pd, asym);
 noscalar:
-    newest = &x->gl_pd;     /* mimic action of canvas_pop() */
+    pd_this->pd_newest = &x->gl_pd;     /* mimic action of canvas_pop() */
     pd_popsym(&x->gl_pd);
     x->gl_loading = 0;
 
@@ -154,19 +152,19 @@ static void scalar_define_save(t_gobj *z, t_binbuf *bb)
 static void *scalarobj_new(t_symbol *s, int argc, t_atom *argv)
 {
     if (!argc || argv[0].a_type != A_SYMBOL)
-        newest = scalar_define_new(s, argc, argv);
+        pd_this->pd_newest = scalar_define_new(s, argc, argv);
     else
     {
         char *str = argv[0].a_w.w_symbol->s_name;
         if (!strcmp(str, "d") || !strcmp(str, "define"))
-            newest = scalar_define_new(s, argc-1, argv+1);
+            pd_this->pd_newest = scalar_define_new(s, argc-1, argv+1);
         else
         {
             error("scalar %s: unknown function", str);
-            newest = 0;
+            pd_this->pd_newest = 0;
         }
     }
-    return (newest);
+    return (pd_this->pd_newest);
 }
 
 void canvas_add_for_class(t_class *c);
